@@ -31,59 +31,62 @@ THE SOFTWARE.
 namespace Ogre {
     //-----------------------------------------------------------------------
     Light::Light()
-        : mLightType(LT_POINT),
+        :
+#ifdef OGRE_NODELESS_POSITIONING
           mPosition(Vector3::ZERO),
+          mDirection(Vector3::NEGATIVE_UNIT_Z),
+          mDerivedPosition(Vector3::ZERO),
+          mDerivedDirection(Vector3::NEGATIVE_UNIT_Z),
+          mDerivedCamRelativePosition(Vector3::ZERO),
+          mDerivedCamRelativeDirty(false),
+          mDerivedTransformDirty(false),
+#endif
           mDiffuse(ColourValue::White),
           mSpecular(ColourValue::Black),
-          mDirection(Vector3::NEGATIVE_UNIT_Z),
           mSpotOuter(Degree(40.0f)),
           mSpotInner(Degree(30.0f)),
           mSpotFalloff(1.0f),
           mSpotNearClip(0.0f),
           mAttenuation(100000.f, 1.f, 0.f, 0.f),
-          mPowerScale(1.0f),
-          mIndexInFrame(0),
-          mOwnShadowFarDist(false),
           mShadowFarDist(0),
           mShadowFarDistSquared(0),
+          mIndexInFrame(0),
           mShadowNearClipDist(-1),
           mShadowFarClipDist(-1),
-          mDerivedPosition(Vector3::ZERO),
-          mDerivedDirection(Vector3::NEGATIVE_UNIT_Z),
-          mDerivedCamRelativePosition(Vector3::ZERO),
-          mDerivedCamRelativeDirty(false),
           mCameraToBeRelativeTo(0),
-          mDerivedTransformDirty(false),
-          mCustomShadowCameraSetup()
+          mPowerScale(1.0f),
+          mLightType(LT_POINT),
+          mOwnShadowFarDist(false)
     {
         //mMinPixelSize should always be zero for lights otherwise lights will disapear
         mMinPixelSize = 0;
     }
     //-----------------------------------------------------------------------
     Light::Light(const String& name) : MovableObject(name),
-        mLightType(LT_POINT),
+#ifdef OGRE_NODELESS_POSITIONING
         mPosition(Vector3::ZERO),
+        mDirection(Vector3::NEGATIVE_UNIT_Z),
+        mDerivedPosition(Vector3::ZERO),
+        mDerivedDirection(Vector3::NEGATIVE_UNIT_Z),
+        mDerivedCamRelativeDirty(false),
+        mDerivedTransformDirty(false),
+#endif
         mDiffuse(ColourValue::White),
         mSpecular(ColourValue::Black),
-        mDirection(Vector3::NEGATIVE_UNIT_Z),
         mSpotOuter(Degree(40.0f)),
         mSpotInner(Degree(30.0f)),
         mSpotFalloff(1.0f),
         mSpotNearClip(0.0f),
         mAttenuation(100000.f, 1.f, 0.f, 0.f),
-        mPowerScale(1.0f),
-        mIndexInFrame(0),
-        mOwnShadowFarDist(false),
         mShadowFarDist(0),
         mShadowFarDistSquared(0),
+        mIndexInFrame(0),
         mShadowNearClipDist(-1),
         mShadowFarClipDist(-1),
-        mDerivedPosition(Vector3::ZERO),
-        mDerivedDirection(Vector3::NEGATIVE_UNIT_Z),
-        mDerivedCamRelativeDirty(false),
         mCameraToBeRelativeTo(0),
-        mDerivedTransformDirty(false),
-        mCustomShadowCameraSetup()
+        mPowerScale(1.0f),
+        mLightType(LT_POINT),
+        mOwnShadowFarDist(false)
     {
         //mMinPixelSize should always be zero for lights otherwise lights will disapear
         mMinPixelSize = 0;
@@ -102,6 +105,7 @@ namespace Ogre {
     {
         return mLightType;
     }
+#ifdef OGRE_NODELESS_POSITIONING
     //-----------------------------------------------------------------------
     void Light::setPosition(Real x, Real y, Real z)
     {
@@ -140,6 +144,7 @@ namespace Ogre {
     {
         return mDirection;
     }
+#endif
     //-----------------------------------------------------------------------
     void Light::setSpotlightRange(const Radian& innerAngle, const Radian& outerAngle, Real falloff)
     {
@@ -221,6 +226,7 @@ namespace Ogre {
     {
         return mPowerScale;
     }
+#ifdef OGRE_NODELESS_POSITIONING
     //-----------------------------------------------------------------------
     void Light::update(void) const
     {
@@ -262,6 +268,7 @@ namespace Ogre {
 
         MovableObject::_notifyMoved();
     }
+#endif
     //-----------------------------------------------------------------------
     const AxisAlignedBox& Light::getBoundingBox(void) const
     {
@@ -285,6 +292,7 @@ namespace Ogre {
     {
         return LightFactory::FACTORY_TYPE_NAME;
     }
+#ifdef OGRE_NODELESS_POSITIONING
     //-----------------------------------------------------------------------
     const Vector3& Light::getDerivedPosition(bool cameraRelative) const
     {
@@ -304,6 +312,7 @@ namespace Ogre {
         update();
         return mDerivedDirection;
     }
+#endif
     //-----------------------------------------------------------------------
     Vector4 Light::getAs4DVector(bool cameraRelativeIfSet) const
     {
@@ -518,7 +527,10 @@ namespace Ogre {
     {
         if (mLightType == LT_DIRECTIONAL)
         {
-            tempSquareDist = 0;
+            // make sure directional lights are always in front
+            // even of point lights at worldPos
+            // tempSquareDist is just a tag for sorting, and nobody will take the sqrt
+            tempSquareDist = -1;
         }
         else
         {
@@ -744,7 +756,9 @@ namespace Ogre {
     void Light::_setCameraRelative(Camera* cam)
     {
         mCameraToBeRelativeTo = cam;
+#ifdef OGRE_NODELESS_POSITONING
         mDerivedCamRelativeDirty = true;
+#endif
     }
     //---------------------------------------------------------------------
     Real Light::_deriveShadowNearClipDistance(const Camera* maincam) const
@@ -755,7 +769,7 @@ namespace Ogre {
             return maincam->getNearClipDistance();
     }
     //---------------------------------------------------------------------
-    Real Light::_deriveShadowFarClipDistance(const Camera* maincam) const
+    Real Light::_deriveShadowFarClipDistance() const
     {
         if (mShadowFarClipDist >= 0)
             return mShadowFarClipDist;
@@ -804,6 +818,10 @@ namespace Ogre {
         //directional light always intersects (check only spotlight and point)
         if (mLightType != LT_DIRECTIONAL)
         {
+#ifndef OGRE_NODELESS_POSITIONING
+            const auto& mDerivedDirection = getDerivedDirection();
+            const auto& mDerivedPosition = mParentNode->_getDerivedPosition();
+#endif
             //Check that the sphere is within the sphere of the light
             isIntersect = container.intersects(Sphere(mDerivedPosition, mAttenuation[0]));
             //If this is a spotlight, check that the sphere is within the cone of the spot light
@@ -832,6 +850,10 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     bool Light::isInLightRange(const Ogre::AxisAlignedBox& container) const
     {
+#ifndef OGRE_NODELESS_POSITIONING
+        const auto& mDerivedDirection = getDerivedDirection();
+        const auto& mDerivedPosition = mParentNode->_getDerivedPosition();
+#endif
         bool isIntersect = true;
         //Check the 2 simple / obvious situations. Light is directional or light source is inside the container
         if ((mLightType != LT_DIRECTIONAL) && (container.intersects(mDerivedPosition) == false))
@@ -947,13 +969,4 @@ namespace Ogre {
 
         return light;
     }
-    //-----------------------------------------------------------------------
-    void LightFactory::destroyInstance( MovableObject* obj)
-    {
-        OGRE_DELETE obj;
-    }
-
-
-
-
 } // Namespace
