@@ -141,7 +141,7 @@ namespace Ogre
     {
         if (mRandProvider)
             return mRandProvider->getRandomUnit();
-        else return Real(rand()) / RAND_MAX;
+        else return Real(rand()) / float(RAND_MAX);
     }
     
     //-----------------------------------------------------------------------
