@@ -145,11 +145,7 @@ namespace Ogre {
 
         // Upfront, lets check whether we have vertex program capability
         RenderSystem* rend = Root::getSingleton().getRenderSystem();
-        bool useVertexPrograms = false;
-        if (rend && rend->getCapabilities()->hasCapability(RSC_VERTEX_PROGRAM))
-        {
-            useVertexPrograms = true;
-        }
+        bool useVertexPrograms = rend;
 
 
         // Look for a position element
@@ -465,14 +461,10 @@ namespace Ogre {
         for (unsigned short b = 0; b <= newDeclaration->getMaxSource(); ++b)
         {
             VertexDeclaration::VertexElementList destElems = newDeclaration->findElementsBySource(b);
-            // Initialise with most restrictive version 
-            // (not really a usable option, but these flags will be removed)
-            HardwareBuffer::Usage final = static_cast<HardwareBuffer::Usage>(
-                HardwareBuffer::HBU_STATIC_WRITE_ONLY | HardwareBuffer::HBU_DISCARDABLE);
-            VertexDeclaration::VertexElementList::iterator v;
-            for (v = destElems.begin(); v != destElems.end(); ++v)
+            // Initialise with most restrictive version
+            int final = HardwareBuffer::HBU_STATIC_WRITE_ONLY;
+            for (VertexElement& destelem : destElems)
             {
-                VertexElement& destelem = *v;
                 // get source
                 const VertexElement* srcelem =
                     vertexDeclaration->findElementBySemantic(
@@ -484,27 +476,17 @@ namespace Ogre {
                 if (srcbuf->getUsage() & HardwareBuffer::HBU_DYNAMIC)
                 {
                     // remove static
-                    final = static_cast<HardwareBuffer::Usage>(
-                        final & ~HardwareBuffer::HBU_STATIC);
+                    final &= ~HardwareBuffer::HBU_STATIC;
                     // add dynamic
-                    final = static_cast<HardwareBuffer::Usage>(
-                        final | HardwareBuffer::HBU_DYNAMIC);
+                    final |= HardwareBuffer::HBU_DYNAMIC;
                 }
-                if (!(srcbuf->getUsage() & HardwareBuffer::HBU_WRITE_ONLY))
+                if (!(srcbuf->getUsage() & HBU_DETAIL_WRITE_ONLY))
                 {
                     // remove write only
-                    final = static_cast<HardwareBuffer::Usage>(
-                        final & ~HardwareBuffer::HBU_WRITE_ONLY);
+                    final &= ~HBU_DETAIL_WRITE_ONLY;
                 }
-                if (!(srcbuf->getUsage() & HardwareBuffer::HBU_DISCARDABLE))
-                {
-                    // remove discardable
-                    final = static_cast<HardwareBuffer::Usage>(
-                        final & ~HardwareBuffer::HBU_DISCARDABLE);
-                }
-                
             }
-            usages.push_back(final);
+            usages.push_back(static_cast<HardwareBuffer::Usage>(final));
         }
         // Call specific method
         reorganiseBuffers(newDeclaration, usages, mgr);
@@ -582,19 +564,9 @@ namespace Ogre {
         closeGapsInBindings();
     }
     //-----------------------------------------------------------------------
-    void VertexData::convertPackedColour(
-        VertexElementType srcType, VertexElementType destType)
+    void VertexData::convertPackedColour(VertexElementType, VertexElementType destType)
     {
-        if (destType != VET_COLOUR_ABGR && destType != VET_COLOUR_ARGB)
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
-                "Invalid destType parameter", "VertexData::convertPackedColour");
-        }
-        if (srcType != VET_COLOUR_ABGR && srcType != VET_COLOUR_ARGB)
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
-                "Invalid srcType parameter", "VertexData::convertPackedColour");
-        }
+        OgreAssert(destType == VET_UBYTE4_NORM, "Not supported");
 
         const VertexBufferBinding::VertexBufferBindingMap& bindMap = 
             vertexBufferBinding->getBindings();
@@ -608,9 +580,7 @@ namespace Ogre {
             for (elemi = elems.begin(); elemi != elems.end(); ++elemi)
             {
                 VertexElement& elem = *elemi;
-                if (elem.getType() == VET_COLOUR || 
-                    ((elem.getType() == VET_COLOUR_ABGR || elem.getType() == VET_COLOUR_ARGB) 
-                    && elem.getType() != destType))
+                if (elem.getType() == _DETAIL_SWAP_RB)
                 {
                     conversionNeeded = true;
                 }
@@ -626,15 +596,11 @@ namespace Ogre {
                     for (elemi = elems.begin(); elemi != elems.end(); ++elemi)
                     {
                         VertexElement& elem = *elemi;
-                        VertexElementType currType = (elem.getType() == VET_COLOUR) ?
-                            srcType : elem.getType();
-                        if (elem.getType() == VET_COLOUR || 
-                            ((elem.getType() == VET_COLOUR_ABGR || elem.getType() == VET_COLOUR_ARGB) 
-                            && elem.getType() != destType))
+                        if (elem.getType() == _DETAIL_SWAP_RB)
                         {
                             uint32* pRGBA;
                             elem.baseVertexPointerToElement(pBase, &pRGBA);
-                            VertexElement::convertColourValue(currType, destType, pRGBA);
+                            VertexElement::convertColourValue(_DETAIL_SWAP_RB, destType, pRGBA);
                         }
                     }
                     pBase = static_cast<void*>(
@@ -650,9 +616,7 @@ namespace Ogre {
                 for (ai = allelems.begin(); ai != allelems.end(); ++ai, ++elemIndex)
                 {
                     const VertexElement& elem = *ai;
-                    if (elem.getType() == VET_COLOUR || 
-                        ((elem.getType() == VET_COLOUR_ABGR || elem.getType() == VET_COLOUR_ARGB) 
-                        && elem.getType() != destType))
+                    if (elem.getType() == _DETAIL_SWAP_RB)
                     {
                         vertexDeclaration->modifyElement(elemIndex, 
                             elem.getSource(), elem.getOffset(), destType, 
@@ -761,6 +725,13 @@ namespace Ogre {
         {
         }
 
+        inline Triangle& operator=(const Triangle& rhs) {
+            a = rhs.a;
+            b = rhs.b;
+            c = rhs.c;
+            return *this;
+        }
+
         inline bool sharesEdge(const Triangle& t) const
         {
             return( (a == t.a && b == t.c) ||
