@@ -127,11 +127,7 @@ namespace Ogre {
             return;
 
         optDisplayFrequency->second.possibleValues.clear();
-        if( !isFullscreen )
-        {
-            optDisplayFrequency->second.possibleValues.push_back( "N/A" );
-        }
-        else
+        if (isFullscreen)
         {
             for (const auto& mode : mGLSupport->getVideoModes())
             {
@@ -149,15 +145,13 @@ namespace Ogre {
             removeDuplicates(optDisplayFrequency->second.possibleValues);
         }
 
-        if (!optDisplayFrequency->second.possibleValues.empty())
+        if (optDisplayFrequency->second.possibleValues.empty())
         {
-            optDisplayFrequency->second.currentValue = optDisplayFrequency->second.possibleValues[0];
-        }
-        else
-        {
-            optVideoMode->second.currentValue = mGLSupport->getVideoModes()[0].getDescription();
-            optDisplayFrequency->second.currentValue = StringConverter::toString(mGLSupport->getVideoModes()[0].refreshRate) + " Hz";
+            optDisplayFrequency->second.possibleValues.push_back("N/A");
+            optDisplayFrequency->second.immutable = true;
         }
+
+        optDisplayFrequency->second.currentValue = optDisplayFrequency->second.possibleValues.front();
     }
 
     //-------------------------------------------------------------------------------------------------//
@@ -165,9 +159,7 @@ namespace Ogre {
     {
         ConfigOptionMap::iterator option = mOptions.find(name);
         if (option == mOptions.end()) {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
-                        "Option named " + name + " does not exist.",
-                        "GLNativeSupport::setConfigOption");
+            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS, "Option named '" + name + "' does not exist.");
         }
         option->second.currentValue = value;
 
@@ -209,9 +201,76 @@ namespace Ogre {
         }
     }
 
+    void GLRenderSystemCommon::_convertProjectionMatrix(const Matrix4& matrix, Matrix4& dest, bool)
+    {
+        // no conversion required for OpenGL
+        dest = matrix;
+
+        if (mIsReverseDepthBufferEnabled)
+        {
+            // Convert depth range from [-1,+1] to [1,0]
+            dest[2][0] = (dest[2][0] - dest[3][0]) * -0.5f;
+            dest[2][1] = (dest[2][1] - dest[3][1]) * -0.5f;
+            dest[2][2] = (dest[2][2] - dest[3][2]) * -0.5f;
+            dest[2][3] = (dest[2][3] - dest[3][3]) * -0.5f;
+        }
+    }
+
     void GLRenderSystemCommon::_getDepthStencilFormatFor(PixelFormat internalColourFormat,
                                                          uint32* depthFormat, uint32* stencilFormat)
     {
         mRTTManager->getBestDepthStencil( internalColourFormat, depthFormat, stencilFormat );
     }
+
+    unsigned int GLRenderSystemCommon::getDisplayMonitorCount() const
+    {
+        return mGLSupport->getDisplayMonitorCount();
+    }
+
+    void GLRenderSystemCommon::registerThread()
+    {
+        OGRE_LOCK_MUTEX(mThreadInitMutex);
+        // This is only valid once we've created the main context
+        if (!mMainContext)
+        {
+            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
+                        "Cannot register a background thread before the main context has been created");
+        }
+
+        // Create a new context for this thread. Cloning from the main context
+        // will ensure that resources are shared with the main context
+        // We want a separate context so that we can safely create GL
+        // objects in parallel with the main thread
+        GLContext* newContext = mMainContext->clone();
+        mBackgroundContextList.push_back(newContext);
+
+        // Bind this new context to this thread.
+        newContext->setCurrent();
+
+        _oneTimeContextInitialization();
+        newContext->setInitialized();
+    }
+
+    void GLRenderSystemCommon::unregisterThread()
+    {
+        // nothing to do here?
+        // Don't need to worry about active context, just make sure we delete
+        // on shutdown.
+    }
+
+    void GLRenderSystemCommon::preExtraThreadsStarted()
+    {
+        OGRE_LOCK_MUTEX(mThreadInitMutex);
+        // free context, we'll need this to share lists
+        if (mCurrentContext)
+            mCurrentContext->endCurrent();
+    }
+
+    void GLRenderSystemCommon::postExtraThreadsStarted()
+    {
+        OGRE_LOCK_MUTEX(mThreadInitMutex);
+        // reacquire context
+        if (mCurrentContext)
+            mCurrentContext->setCurrent();
+    }
 }
